Block-H: DCPS entity header stubs (Spec idl4-cpp-1.0 7.6 + dds-psm-cxx-1.0 8.1).
Emits class declarations and method signatures for the core DCPS entities:
dds::domain::DomainParticipantdds::pub::Publisher+dds::pub::DataWriter<T>dds::sub::Subscriber+dds::sub::DataReader<T>dds::topic::Topic<T>dds::core::Entity(base class)
The full implementation is not part of the code generator — that is the responsibility of the hand-written DDS-PSM-CXX runtime (cluster C5.2 templates). The code generator only provides the header skeleton against which user code is compiled.
Functions
- dcps_
class_ names - Returns the list of fully-qualified class names emitted by Block-H.
- emit_
dcps_ header - Writes the complete DCPS header.